@@ -1,6 +1,7 @@
 #![doc(html_root_url = "https://sfackler.github.io/rust-security-framework/doc/v0.2")]
 #![allow(bad_style)]
 
+extern crate MacTypes_sys;
 extern crate core_foundation_sys;
 extern crate libc;
 
@@ -8,6 +9,8 @@ extern crate libc;
 pub mod access;
 pub mod base;
 pub mod certificate;
+#[cfg(target_os = "macos")]
+pub mod certificate_oids;
 pub mod cipher_suite;
 #[cfg(target_os = "macos")]
 pub mod digest_transform;
